@@ -82,7 +82,7 @@ class Connection:
 
     Note:
     ----
-        SSL currently only works with the py-amqp, and qpid
+        SSL currently only works with the py-amqp, qpid and redis
         transports.  For other transports you can use stunnel.
 
     Arguments:
@@ -524,8 +524,7 @@ class Connection:
             on_revive (Callable): Optional callback called whenever
                 revival completes successfully
             retry_errors (tuple): Optional list of errors to retry on
-                regardless of the connection state. Must provide max_retries
-                if this is specified.
+                regardless of the connection state.
 
         Examples
         --------
@@ -543,12 +542,6 @@ class Connection:
         """
         if retry_errors is None:
             retry_errors = tuple()
-        elif max_retries is None:
-            # If the retry_errors is specified, but max_retries is not,
-            # this could lead into an infinite loop potentially.
-            raise ValueError(
-                "max_retries must be specified if retry_errors is specified"
-            )
 
         def _ensured(*args, **kwargs):
             got_connection = 0
