@@ -176,6 +176,14 @@ class InvalidQueueException(Exception):
     """Predefined queues are being used and configuration is not valid."""
 
 
+class AccessDeniedQueueException(Exception):
+    """Raised when access to the AWS queue is denied.
+
+    This may occur if the permissions are not correctly set or the
+    credentials are invalid.
+    """
+
+
 class QoS(virtual.QoS):
     """Quality of Service guarantees implementation for SQS."""
 
@@ -605,10 +613,10 @@ class Channel(virtual.Channel):
         Uses long polling and returns :class:`~vine.promises.promise`.
         """
         return connection.receive_message(
-            queue_url,
-            number_messages=count,
+            queue_name, queue_url, number_messages=count,
             wait_time_seconds=self.wait_time_seconds,
-            callback=callback)
+            callback=callback,
+        )
 
     def _restore(self, message,
                  unwanted_delivery_info=('sqs_message', 'sqs_queue')):
@@ -633,7 +641,11 @@ class Channel(virtual.Channel):
                     QueueUrl=message['sqs_queue'],
                     ReceiptHandle=sqs_message['ReceiptHandle']
                 )
-            except ClientError:
+            except ClientError as exception:
+                if exception.response['Error']['Code'] == 'AccessDenied':
+                    raise AccessDeniedQueueException(
+                        exception.response["Error"]["Message"]
+                        )
                 super().basic_reject(delivery_tag)
             else:
                 super().basic_ack(delivery_tag)
@@ -662,6 +674,12 @@ class Channel(virtual.Channel):
 
     def close(self):
         super().close()
+        # if self._asynsqs:
+        #     try:
+        #         self.asynsqs().close()
+        #     except AttributeError as exc:  # FIXME ???
+        #         if "can't set attribute" not in str(exc):
+        #             raise
 
     def new_sqs_client(self, region, access_key_id,
                        secret_access_key, session_token=None):
