@@ -11,7 +11,6 @@ import os
 import random
 import string
 from datetime import datetime, timedelta
-from operator import itemgetter
 from queue import Empty
 from unittest.mock import Mock, patch
 
@@ -458,21 +457,23 @@ class test_Channel:
         # which is already a mock thanks to `setup` above, we just need to
         # mock the async-specific methods (as test_AsyncSQSConnection does)
         async_sqs_conn = self.channel.asynsqs(self.queue_name)
-        async_sqs_conn.receive_message = Mock(name='X.receive_message')
+        async_sqs_conn.get_list = Mock(name='X.get_list')
 
         # Call key method
         self.channel._get_bulk_async(self.queue_name)
 
-        assert async_sqs_conn.receive_message.call_count == 1
-
-        args, kwargs = async_sqs_conn.receive_message.call_args
-        (q_url, ) = args
-        (number_messages, wait_time_seconds, _) = itemgetter(
-            'number_messages', 'wait_time_seconds', 'callback'
-        )(kwargs)
-        assert q_url == self.channel.sqs().get_queue_url(self.queue_name).url
-        assert number_messages == SQS.SQS_MAX_MESSAGES
-        assert wait_time_seconds == self.channel.wait_time_seconds
+        assert async_sqs_conn.get_list.call_count == 1
+        get_list_args = async_sqs_conn.get_list.call_args[0]
+        get_list_kwargs = async_sqs_conn.get_list.call_args[1]
+        assert get_list_args[0] == 'ReceiveMessage'
+        assert get_list_args[1] == {
+            'MaxNumberOfMessages': SQS.SQS_MAX_MESSAGES,
+            'AttributeName.1': 'ApproximateReceiveCount',
+            'WaitTimeSeconds': self.channel.wait_time_seconds,
+        }
+        assert get_list_args[3] == \
+               self.channel.sqs().get_queue_url(self.queue_name).url
+        assert get_list_kwargs['parent'] == self.queue_name
 
     def test_drain_events_with_empty_list(self):
         def mock_can_consume():
@@ -646,6 +647,46 @@ class test_Channel:
         basic_reject_mock.assert_called_with(2)
         assert not basic_ack_mock.called
 
+    @patch('kombu.transport.virtual.base.Channel.basic_ack')
+    @patch('kombu.transport.virtual.base.Channel.basic_reject')
+    def test_basic_ack_access_denied(self, basic_reject_mock, basic_ack_mock):
+        """Test that basic_ack raises AccessDeniedQueueException when
+           access is denied"""
+        message = {
+            'sqs_message': {
+                'ReceiptHandle': '2'
+            },
+            'sqs_queue': 'testing_queue'
+        }
+        error_response = {
+            'Error': {
+                'Code': 'AccessDenied',
+                'Message': """An error occurred (AccessDenied) when calling the
+                              DeleteMessage operation."""
+            }
+        }
+        operation_name = 'DeleteMessage'
+
+        mock_messages = Mock()
+        mock_messages.delivery_info = message
+        self.channel.qos.append(mock_messages, 2)
+        self.channel.sqs().delete_message = Mock()
+        self.channel.sqs().delete_message.side_effect = ClientError(
+            error_response=error_response,
+            operation_name=operation_name
+        )
+
+        # Expecting the custom AccessDeniedQueueException to be raised
+        with pytest.raises(SQS.AccessDeniedQueueException):
+            self.channel.basic_ack(2)
+
+        self.sqs_conn_mock.delete_message.assert_called_with(
+            QueueUrl=message['sqs_queue'],
+            ReceiptHandle=message['sqs_message']['ReceiptHandle']
+        )
+        assert not basic_reject_mock.called
+        assert not basic_ack_mock.called
+
     def test_reject_when_no_predefined_queues(self):
         connection = Connection(transport=SQS.Transport, transport_options={})
         channel = connection.channel()
