@@ -79,6 +79,21 @@ class test_mongodb_uri_parsing:
 
         assert dbname == 'kombu_default'
 
+    def test_custom_port(self):
+        url = 'mongodb://localhost:27018'
+        channel = _create_mock_connection(url).default_channel
+        hostname, dbname, options = channel._parse_uri()
+
+        assert hostname == 'mongodb://localhost:27018'
+
+    def test_replicaset_hosts(self):
+        url = 'mongodb://mongodb1.example.com:27317,mongodb2.example.com:27017/?replicaSet=test_rs'  # noqa
+        channel = _create_mock_connection(url).default_channel
+        hostname, dbname, options = channel._parse_uri()
+
+        assert hostname == 'mongodb://mongodb1.example.com:27317,mongodb2.example.com:27017/?replicaSet=test_rs'  # noqa
+        assert options['replicaset'] == 'test_rs'
+
     def test_custom_database(self):
         url = 'mongodb://localhost/dbname'
         channel = _create_mock_connection(url).default_channel
