@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import socket
 
 import pytest
@@ -59,8 +61,8 @@ class test_PyroTransport:
         with pytest.raises(socket.timeout):
             self.c.drain_events(timeout=0.1)
 
-        del(c1)  # so pyflakes doesn't complain.
-        del(c2)
+        del c1  # so pyflakes doesn't complain.
+        del c2
 
     @pytest.mark.skip("requires running Pyro nameserver and Kombu Broker")
     def test_drain_events_unregistered_queue(self):
